==> kea-docs-2.0.3-2-x86_64.pkg.tar.zst: usr/share/doc/kea/devel/dir_ef78df514e3b716ecb3355943dbac395.js <==
var dir_ef78df514e3b716ecb3355943dbac395 =
[
    [ "audit_entry.cc", "d8/d75/audit__entry_8cc.html", null ],
    [ "audit_entry.h", "da/d76/audit__entry_8h.html", "da/d76/audit__entry_8h" ],
    [ "backend_selector.cc", "d7/d6f/backend__selector_8cc.html", null ],
    [ "backend_selector.h", "d9/d31/backend__selector_8h.html", [
      [ "isc::db::BackendSelector", "d2/d26/classisc_1_1db_1_1BackendSelector.html", "d2/d26/classisc_1_1db_1_1BackendSelector" ]
    ] ],
    [ "database_connection.cc", "db/dce/database__connection_8cc.html", null ],
    [ "database_connection.h", "df/d67/database__connection_8h.html", "df/d67/database__connection_8h" ],
    [ "db_exceptions.h", "d3/dab/db__exceptions_8h.html", [
      [ "isc::db::AmbiguousDatabase", "de/dcf/classisc_1_1db_1_1AmbiguousDatabase.html", "de/dcf/classisc_1_1db_1_1AmbiguousDatabase" ],
      [ "isc::db::DataTruncated", "d4/d41/classisc_1_1db_1_1DataTruncated.html", "d4/d41/classisc_1_1db_1_1DataTruncated" ],
      [ "isc::db::DbConfigError", "d4/db6/classisc_1_1db_1_1DbConfigError.html", "d4/db6/classisc_1_1db_1_1DbConfigError" ],
      [ "isc::db::DuplicateEntry", "d1/d94/classisc_1_1db_1_1DuplicateEntry.html", "d1/d94/classisc_1_1db_1_1DuplicateEntry" ],
      [ "isc::db::InvalidAddressFamily", "df/ddf/classisc_1_1db_1_1InvalidAddressFamily.html", "df/ddf/classisc_1_1db_1_1InvalidAddressFamily" ],
      [ "isc::db::InvalidRange", "de/d7f/classisc_1_1db_1_1InvalidRange.html", "de/d7f/classisc_1_1db_1_1InvalidRange" ],
      [ "isc::db::MultipleRecords", "d2/df9/classisc_1_1db_1_1MultipleRecords.html", "d2/df9/classisc_1_1db_1_1MultipleRecords" ],
      [ "isc::db::NoSuchDatabase", "d7/db9/classisc_1_1db_1_1NoSuchDatabase.html", "d7/db9/classisc_1_1db_1_1NoSuchDatabase" ],
      [ "isc::db::NullKeyError", "d5/d90/classisc_1_1db_1_1NullKeyError.html", "d5/d90/classisc_1_1db_1_1NullKeyError" ],
      [ "isc::db::ReadOnlyDb", "d6/d31/classisc_1_1db_1_1ReadOnlyDb.html", "d6/d31/classisc_1_1db_1_1ReadOnlyDb" ],
      [ "isc::db::StatementNotApplied", "d8/de3/classisc_1_1db_1_1StatementNotApplied.html", "d8/de3/classisc_1_1db_1_1StatementNotApplied" ]
    ] ],
    [ "db_log.cc", "d8/dcb/db__log_8cc.html", "d8/dcb/db__log_8cc" ],
    [ "db_log.h", "d5/d35/db__log_8h.html", "d5/d35/db__log_8h" ],
    [ "db_messages.cc", "d0/df7/db__messages_8cc.html", "d0/df7/db__messages_8cc" ],
    [ "db_messages.h", "d3/d17/db__messages_8h.html", null ],
    [ "dbaccess_parser.cc", "de/d73/dbaccess__parser_8cc.html", null ],
    [ "dbaccess_parser.h", "d8/d2c/dbaccess__parser_8h.html", [
      [ "isc::db::DbAccessParser", "d7/d69/classisc_1_1db_1_1DbAccessParser.html", "d7/d69/classisc_1_1db_1_1DbAccessParser" ]
    ] ],
    [ "server.cc", "d9/d80/server_8cc.html", null ],
    [ "server.h", "d8/dc3/server_8h.html", "d8/dc3/server_8h" ],
    [ "server_collection.cc", "d2/d85/server__collection_8cc.html", null ],
    [ "server_collection.h", "d1/d69/server__collection_8h.html", "d1/d69/server__collection_8h" ],
    [ "server_selector.cc", "d3/df2/server__selector_8cc.html", null ],
    [ "server_selector.h", "d3/d0c/server__selector_8h.html", [
      [ "isc::db::ServerSelector", "d9/df6/classisc_1_1db_1_1ServerSelector.html", "d9/df6/classisc_1_1db_1_1ServerSelector" ]
    ] ]
];

==> kea-docs-2.2.0-2-x86_64.pkg.tar.zst: usr/share/doc/kea/devel/dir_ef78df514e3b716ecb3355943dbac395.js <==
var dir_ef78df514e3b716ecb3355943dbac395 =
[
    [ "audit_entry.cc", "d8/d75/audit__entry_8cc.html", null ],
    [ "audit_entry.h", "da/d76/audit__entry_8h.html", "da/d76/audit__entry_8h" ],
    [ "backend_selector.cc", "d7/d6f/backend__selector_8cc.html", null ],
    [ "backend_selector.h", "d9/d31/backend__selector_8h.html", [
      [ "isc::db::BackendSelector", "d2/d26/classisc_1_1db_1_1BackendSelector.html", "d2/d26/classisc_1_1db_1_1BackendSelector" ]
    ] ],
    [ "database_connection.cc", "db/dce/database__connection_8cc.html", null ],
    [ "database_connection.h", "df/d67/database__connection_8h.html", "df/d67/database__connection_8h" ],
    [ "db_exceptions.h", "d3/dab/db__exceptions_8h.html", [
      [ "isc::db::AmbiguousDatabase", "de/dcf/classisc_1_1db_1_1AmbiguousDatabase.html", "de/dcf/classisc_1_1db_1_1AmbiguousDatabase" ],
      [ "isc::db::DataTruncated", "d4/d41/classisc_1_1db_1_1DataTruncated.html", "d4/d41/classisc_1_1db_1_1DataTruncated" ],
      [ "isc::db::DbConfigError", "d4/db6/classisc_1_1db_1_1DbConfigError.html", "d4/db6/classisc_1_1db_1_1DbConfigError" ],
      [ "isc::db::DuplicateEntry", "d1/d94/classisc_1_1db_1_1DuplicateEntry.html", "d1/d94/classisc_1_1db_1_1DuplicateEntry" ],
      [ "isc::db::InvalidAddressFamily", "df/ddf/classisc_1_1db_1_1InvalidAddressFamily.html", "df/ddf/classisc_1_1db_1_1InvalidAddressFamily" ],
      [ "isc::db::InvalidRange", "de/d7f/classisc_1_1db_1_1InvalidRange.html", "de/d7f/classisc_1_1db_1_1InvalidRange" ],
      [ "isc::db::MultipleRecords", "d2/df9/classisc_1_1db_1_1MultipleRecords.html", "d2/df9/classisc_1_1db_1_1MultipleRecords" ],
      [ "isc::db::NoSuchDatabase", "d7/db9/classisc_1_1db_1_1NoSuchDatabase.html", "d7/db9/classisc_1_1db_1_1NoSuchDatabase" ],
      [ "isc::db::NullKeyError", "d5/d90/classisc_1_1db_1_1NullKeyError.html", "d5/d90/classisc_1_1db_1_1NullKeyError" ],
      [ "isc::db::ReadOnlyDb", "d6/d31/classisc_1_1db_1_1ReadOnlyDb.html", "d6/d31/classisc_1_1db_1_1ReadOnlyDb" ]
    ] ],
    [ "db_log.cc", "d8/dcb/db__log_8cc.html", "d8/dcb/db__log_8cc" ],
    [ "db_log.h", "d5/d35/db__log_8h.html", "d5/d35/db__log_8h" ],
    [ "db_messages.cc", "d0/df7/db__messages_8cc.html", "d0/df7/db__messages_8cc" ],
    [ "db_messages.h", "d3/d17/db__messages_8h.html", null ],
    [ "dbaccess_parser.cc", "de/d73/dbaccess__parser_8cc.html", null ],
    [ "dbaccess_parser.h", "d8/d2c/dbaccess__parser_8h.html", [
      [ "isc::db::DbAccessParser", "d7/d69/classisc_1_1db_1_1DbAccessParser.html", "d7/d69/classisc_1_1db_1_1DbAccessParser" ]
    ] ],
    [ "server.cc", "d9/d80/server_8cc.html", null ],
    [ "server.h", "d8/dc3/server_8h.html", "d8/dc3/server_8h" ],
    [ "server_collection.cc", "d2/d85/server__collection_8cc.html", null ],
    [ "server_collection.h", "d1/d69/server__collection_8h.html", "d1/d69/server__collection_8h" ],
    [ "server_selector.cc", "d3/df2/server__selector_8cc.html", null ],
    [ "server_selector.h", "d3/d0c/server__selector_8h.html", [
      [ "isc::db::ServerSelector", "d9/df6/classisc_1_1db_1_1ServerSelector.html", "d9/df6/classisc_1_1db_1_1ServerSelector" ]
    ] ]
];
